==========================
Core Utilities for Tendril
==========================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-core.svg
        :target: https://travis-ci.org/chintal/tendril-utils-core

.. image:: https://img.shields.io/pypi/v/tendril-utils-core.svg
        :target: https://pypi.python.org/pypi/tendril-utils-core

* License: AGPLv3
* Documentation: http://tendril-utils-core.readthedocs.org


tendril.utils.config
--------------------

Master configuration container for Tendril. This exists independently for
packaging reasons only, and does not have a significant footprint or
independent utility.


tendril.utils.log
-----------------

Master logging control interface for Tendril.

